summaryrefslogtreecommitdiffstats
path: root/quanta/src/dtds.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/src/dtds.h')
-rw-r--r--quanta/src/dtds.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/quanta/src/dtds.h b/quanta/src/dtds.h
index 4f351182..0ecf30cb 100644
--- a/quanta/src/dtds.h
+++ b/quanta/src/dtds.h
@@ -44,7 +44,7 @@ struct DTDStruct;
/** @short This class manages the DTD's for Quanta.
*
* The constructor only loads the necessary information from the description.rc file.
* The rest is later loaded on demand of the tqfind() function.
*/
class DTDs : public TQObject
{
@@ -73,10 +73,10 @@ public:
* @param dtdName name of the dtd, will be converted to lowercase inside
* @return the found dtd structure
*/
- const DTDStruct * tqfind (const TQString &dtdName)
+ const DTDStruct * find (const TQString &dtdName)
{
-// kdDebug(24000) << "dtds::tqfind " << dtdName << endl;
- DTDStruct *dtd = m_dict->tqfind(dtdName.lower()) ;
+// kdDebug(24000) << "dtds::find " << dtdName << endl;
+ DTDStruct *dtd = m_dict->find(dtdName.lower()) ;
if (dtd && ! dtd->loaded ) readTagDir2(dtd);
return dtd;
}
@@ -93,7 +93,7 @@ public:
*/
TQString getDTDNickNameFromName(const TQString& name)
{
- DTDStruct *dtd = m_dict->tqfind(name);
+ DTDStruct *dtd = m_dict->find(name);
if ( dtd )
return dtd->nickName;
else
@@ -44,7 +44,7 @@ struct DTDStruct;
*
* The constructor only loads the necessary information from the description.rc file.
- * The rest is later loaded on demand of the tqfind() function.
+ * The rest is later loaded on demand of the find() function.
*/
class DTDs : public TQObject